{"": "", "Power off": "G\u00fcc\u00fc kapat", "Hibernate": "", "Shutdown and reboot the system": "", "Power": "G\u00fc\u00e7", "Plugged in": "Ba\u011fland\u0131", "System uptime": "Sistem aktif s\u00fcresi", "{{battery.voltage}} V": "{{battery.voltage}} V", "Reboot": "Yeniden ba\u015flat", "Suspend": "Ask\u0131ya al", "Power state": "G\u00fc\u00e7 durumu", "Batteries": "Piller", "Not available": "Kullan\u0131labilir de\u011fil", "No batteries detected": "Pil bulunamad\u0131", "Discharging at {{battery.rate}} W": "", "Adapters": "Ba\u011fda\u015ft\u0131r\u0131c\u0131lar", "Charging": "\u015earj oluyor", "No adapters detected": "Adapt\u00f6r bulunamad\u0131"}