{"": "", "Power off": "Izklop", "Hibernate": "Hibernacija", "Shutdown and reboot the system": "Zaustavi in ponovno za\u017eeni sistem", "Power": "Napajanje", "Plugged in": "Priklopljeno v omre\u017eje", "System uptime": "\u010cas od zagona sistema", "{{battery.voltage}} V": "{{battery.voltage}} V", "Reboot": "Ponovni zagon", "Suspend": "Mirovanje", "Power state": "Stanje porabe", "Batteries": "Baterije", "Not available": "Ni na voljo", "No batteries detected": "Ni zaznanih baterij", "Discharging at {{battery.rate}} W": "Praznjenje pri {{battery.rate}} W", "Adapters": "Vmesniki", "Charging": "Polnjenje", "No adapters detected": "Ni zaznanih vmesnikov"}