{"": "", "Power off": "Desligar", "Hibernate": "Hibernar", "Shutdown and reboot the system": "Desligamento e reinicializa\u00e7\u00e3o do sistema", "Power": "Energia", "Plugged in": "Conectado", "System uptime": "Tempo ligado do sistema", "{{battery.voltage}} V": "{{battery.voltage}} V", "Reboot": "Reiniciar", "Suspend": "Suspender", "Power state": "Estado de energia", "Batteries": "Baterias", "Not available": "Indispon\u00edvel", "No batteries detected": "Nenhuma bateria detectada", "Discharging at {{battery.rate}} W": "Descarregando em {{battery.rate}} W", "Adapters": "Adaptadores", "Charging": "Carregando", "No adapters detected": "Nenhum adaptador detectado"}