{"": "", "Power off": "Ausschalten", "Hibernate": "Ruhezustand", "Shutdown and reboot the system": "Herunterfahren und Neustart des Systems", "Power": "Power", "Plugged in": "Eingesteckt", "System uptime": "Uptime", "{{battery.voltage}} V": "{{battery.voltage}} V", "Reboot": "Neustart", "Suspend": "Bereitschaft", "Power state": "Status", "Batteries": "Batterien", "Not available": "Nicht verf\u00fcgbar", "No batteries detected": "Keine Akkus erkannt", "Discharging at {{battery.rate}} W": "Entladung mit {{battery.rate}} W", "Adapters": "Adapter", "Charging": "Aufladen", "No adapters detected": "Keine Adapter erkannt"}