{"": "", "Power off": "", "Hibernate": "Slaapstand", "Shutdown and reboot the system": "Afsluiten en opnieuw opstarten van het systeem", "Power": "Vermogen", "Plugged in": "Aangesloten", "System uptime": "", "{{battery.voltage}} V": "{{battery.voltage}} V", "Reboot": "", "Suspend": "", "Power state": "Vermogen status", "Batteries": "Accu\u2019s", "Not available": "Niet beschikbaar", "No batteries detected": "Geen batterijen gedetecteerd", "Discharging at {{battery.rate}} W": "Ontladen op {{battery.rate}} W", "Adapters": "Adapters", "Charging": "Aan het opladen", "No adapters detected": "Geen adapters gedetecteerd"}