{"": "", "Power off": "Spegni", "Hibernate": "Ibernazione", "Shutdown and reboot the system": "Arresto e riavvio del sistema", "Power": "Alimentazione", "Plugged in": "Collegato", "System uptime": "Tempo di accensione del sistema", "{{battery.voltage}} V": "{{battery.voltage}} V", "Reboot": "Riavvia", "Suspend": "Sospensione", "Power state": "Stato di alimentazione", "Batteries": "Batterie", "Not available": "Non disponibile", "No batteries detected": "Batterie non rilevate", "Discharging at {{battery.rate}} W": "Scaricamento a {{battery.rate}} W", "Adapters": "Adattatori", "Charging": "In carica", "No adapters detected": "Nessun adattatore rilevato"}