{"": "", "Power off": "", "Hibernate": "Mise en veille prolong\u00e9e", "Shutdown and reboot the system": "Arr\u00eater et red\u00e9marrer le syst\u00e8me", "Power": "", "Plugged in": "", "System uptime": "", "{{battery.voltage}} V": "", "Reboot": "", "Suspend": "", "Power state": "", "Batteries": "", "Not available": "", "No batteries detected": "Aucune batterie d\u00e9tect\u00e9e", "Discharging at {{battery.rate}} W": "", "Adapters": "", "Charging": "Rechargement en cours", "No adapters detected": ""}