{"": "", "Power off": "", "Hibernate": "", "Shutdown and reboot the system": "", "Power": "", "Plugged in": "", "System uptime": "", "{{battery.voltage}} V": "{{battery.voltage}} V", "Reboot": "", "Suspend": "", "Power state": "", "Batteries": "", "Not available": "", "No batteries detected": "", "Discharging at {{battery.rate}} W": "La desc\u00e0rrega de {{battery.rate}} W", "Adapters": "Adaptadors", "Charging": "", "No adapters detected": ""}